@@ -4,19 +4,16 @@
 
   
   cat('---------------------------------------------------------------------------------',fill=T)
-  cat('-   Geneland-2.0.8 is loaded                                                    -',fill=T)
-  cat('-                                                                               -',fill=T)
+  cat('-   Geneland-2.0.9 is loaded                                                    -',fill=T)
   cat('-                                                                               -',fill=T)
   cat('-       *** Please ***                                                          -',fill=T)
   cat('-                                                                               -',fill=T)
-  cat('-      - Send a very short email at guillot@inapg.inra.fr                       -',fill=T)
+  cat('-      - Send a short email at guillot@inapg.inra.fr                            -',fill=T)
   cat('-        notifying that you are using Geneland.                                 -',fill=T)
-  cat('-        You will be added to the Geneland mailing list and be informed         -',fill=T)
-  cat('-        about updates and related works.                                       -',fill=T)
   cat('-                                                                               -',fill=T)  
   cat('-      - See                                                                    -',fill=T)
   cat('-        www.inapg.inra.fr/ens_rech/mathinfo/personnel/guillot/Geneland.html    -',fill=T)  
-  cat('-        for informations                                                       -',fill=T)
+  cat('-        for an introduction to Geneland                                        -',fill=T)
   cat('---------------------------------------------------------------------------------',fill=T)
 
 }
@@ -24,3 +21,4 @@
 
  
  
+ 
